==> kubernetes-model-storageclass-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/storage/v1beta1/CSINodeBuilder.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSINodeBuilder extends io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluentImpl<io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeBuilder>{
  public CSINodeBuilder() {
    this(false);
  }
  public CSINodeBuilder(java.lang.Boolean validationEnabled) {
    this(new CSINode(), validationEnabled);
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluent<?> fluent) {
    this(fluent, false);
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSINode(), validationEnabled);
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode instance) {
    this(fluent, instance, false);
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    this.validationEnabled = validationEnabled; 
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode instance) {
    this(instance,false);
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode build() {
    CSINode buildable = new CSINode(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSINodeBuilder that = (CSINodeBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-storageclass-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/storage/v1beta1/CSINodeBuilder.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSINodeBuilder extends io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluentImpl<io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeBuilder>{
  public CSINodeBuilder() {
    this(false);
  }
  public CSINodeBuilder(java.lang.Boolean validationEnabled) {
    this(new CSINode(), validationEnabled);
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluent<?> fluent) {
    this(fluent, false);
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSINode(), validationEnabled);
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode instance) {
    this(fluent, instance, false);
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode instance) {
    this(instance,false);
  }
  public CSINodeBuilder(io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.storage.v1beta1.CSINodeFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.storage.v1beta1.CSINode build() {
    CSINode buildable = new CSINode(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSINodeBuilder that = (CSINodeBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
